#!/usr/bin/env python3

from dataclasses import dataclass
from enum import Enum
from os import PathLike
from yaml import safe_load
import re
## custom modules
from modules.Logger import *


logger = logging.getLogger(__name__)
logger.setLevel(level=logging.DEBUG)


def parseString(string):
    if re.match(r'[A-Z]?[a-z0-9]+|[A-Z]+(?=[A-Z]|$)', string):
        return re.findall(r'[A-Z]?[a-z0-9]+|[A-Z]+(?=[A-Z]|$)', string)
    else:
        raise Exception('Could not determine pattern for parsing.')


def loadYaml(path: str | PathLike):
    """
    Returns a YAML file contents.
    """
    with open(path, 'r') as f:
        return safe_load(f)


class Platform(str, Enum):
    gcp = "gcp"
    aws = "aws"


@dataclass
class GcpCollectionTarget:
    name: str
    namespace: str
    source: str
    multiKey: bool = True
    encodingStrategy: str = None
    aws_replication: bool = False
    region: str = 'us-west-2'

    def __str__(cls):
        return f'{type(cls).__name__}({cls.name})'


@dataclass
class AwsCollectionTarget:
    name: str
    region: str = 'us-west-2'

    def __str__(cls):
        return f'{type(cls).__name__}({cls.name})'
