#!/usr/bin/env python3

from datetime import datetime
from os import getenv
from pathlib import Path
import logging

## Set up logging
logpath = getenv('LOGPATH', 'tmp')
logfile = Path.cwd().joinpath(logpath, '{:%Y%m%d-%H}.log'.format(datetime.now()))
logfile.parent.mkdir(parents=True, exist_ok=True)
logging.basicConfig(
    level=logging.WARN,
    format='%(asctime)s | %(name)-12s | %(levelname)-8s | %(lineno)04d | %(message)s',
    filename=logfile,
    filemode='w'
)

# set up logging to console
console = logging.StreamHandler()
console.setLevel(logging.INFO)
# set a format which is simpler for console use
formatter = logging.Formatter('%(message)s')
console.setFormatter(formatter)
# add the handler to the root logger
logging.getLogger('').addHandler(console)

logger = logging.getLogger(__name__)